package com.brilliance.isc.funds.fxtlop.check;

import com.brilliance.isc.common.transaction.newcheck.AbstractModuleValidator;
import com.brilliance.isc.common.transaction.newcheck.ValidResult;
import com.brilliance.isc.common.transaction.newcheck.Validate;
import com.brilliance.isc.funds.bo.funds.FxtlopStoreBo;
import com.brilliance.mda.runtime.mda.util.MdaUtils;
import org.springframework.stereotype.Component;

import javax.annotation.PostConstruct;
import java.math.BigDecimal;
import java.util.HashMap;
import java.util.Map;

/**
 * @program: isc-funds
 * @ClassName: FxtlopValidator
 * @description: 结售汇平盘登记 Fxtlop 校验
 * @author: wangweidong
 * @create: 2024-10-08 16:42
 */
@Component
public class FxtlopValidator extends AbstractModuleValidator<FxtlopStoreBo> {


    @Override
    @PostConstruct
    public void register() {
        super.register();
    }

    @Override
    public Map<String, String> validate(FxtlopStoreBo vo) {
        Map<String, String> maps = new HashMap<>();
        maps.putAll(super.validate(vo));
        return maps;
    }

    /**
     *   source:fxtlop.0011.script
     */
    @Validate(path="fxdgrp.rec.opndat")
    public ValidResult checkFxdgrpRecOpndatN1000(FxtlopStoreBo vo){
        if( MdaUtils.isEmpty(vo.getFxdgrp().getRec().getOpndat()) )
        {
            return errorMandatory();
        }
        return null;
    }

    /**
     *   source:fxtlop.0012.script
     */
    @Validate(path="fxdgrp.rec.valdat")
    public ValidResult checkFxdgrpRecValdatN1000(FxtlopStoreBo vo){
        if( MdaUtils.isEmpty(vo.getFxdgrp().getRec().getValdat()) )
        {
            return errorMandatory();
        }
        return null;
    }

    /**
     *   source:fxtlop.0013.script
     */
    @Validate(path="fxdgrp.rec.rat")
    public ValidResult checkFxdgrpRecRatN1000(FxtlopStoreBo vo){
        if( MdaUtils.isEmpty(vo.getFxdgrp().getRec().getRat()) )
        {
            return errorMandatory();
        }
        return null;
    }

    /**
     *   source:fxtlop.0014.script
     */
    @Validate(path="fxdgrp.apl.pts.extkey")
    public ValidResult checkFxdgrpAplPtsExtkeyN1000(FxtlopStoreBo vo){
        if( MdaUtils.isEmpty(vo.getFxdgrp().getApl().getPts().getExtkey()) )
        {
            return errorMandatory();
        }
        return null;
    }
}
