package com.brilliance.isc.funds.fxtsss.check;

import com.brilliance.isc.common.transaction.newcheck.AbstractModuleValidator;
import com.brilliance.isc.common.transaction.newcheck.ValidResult;
import com.brilliance.isc.common.transaction.newcheck.Validate;
import com.brilliance.isc.funds.bo.funds.FxtsssStoreBo;
import com.brilliance.mda.runtime.mda.util.MdaUtils;
import com.brilliance.mda.runtime.mda.util.Strings;
import org.springframework.stereotype.Component;

import javax.annotation.PostConstruct;
import java.util.HashMap;
import java.util.Map;

/**
 * @program: isc-funds
 * @ClassName: FxtsssValidator
 * @description: 即期售汇 Fxtsss 校验
 * @author: huangshunlin
 * @create: 2024-10-08 15:38
 */
@Component
public class FxtsssValidator extends AbstractModuleValidator<FxtsssStoreBo> {


    @Override
    @PostConstruct
    public void register() {
        super.register();
    }

    @Override
    public Map<String, String> validate(FxtsssStoreBo vo) {
        Map<String, String> maps = new HashMap<>();
        maps.putAll(super.validate(vo));
        return maps;
    }

    /**
     * source:fxtsss.0017.script
     */
    @Validate(path = "fxdgrp.rec.trnman")
    public ValidResult checkFxdgrpRecTrnmanN1000(FxtsssStoreBo bo) {
        if (MdaUtils.isEmpty(bo.getFxdgrp().getRec().getTrnman())) {
            return errorMandatory();
        }
        return null;
    }

    /**
     * source:fxtsss.0018.script
     */
    @Validate(path = "fxdgrp.rec.trdint")
    public ValidResult checkFxdgrpRecTrdintN1000(FxtsssStoreBo bo) {
        if (MdaUtils.compareTo(Strings.mid(bo.getFxdgrp().getRec().getFxtyp(), 2, 1), "B") == 0 && MdaUtils.isEmpty(bo.getFxdgrp().getRec().getTrdint())) {
            return errorMandatory();
        }
        return null;
    }

    /**
     * source:fxtsss.0019.script
     */
    @Validate(path = "fxdgrp.rec.trdout")
    public ValidResult checkFxdgrpRecTrdoutN1000(FxtsssStoreBo bo) {
        if (MdaUtils.compareTo(Strings.mid(bo.getFxdgrp().getRec().getFxtyp(), 2, 1), "S") == 0 && MdaUtils.isEmpty(bo.getFxdgrp().getRec().getTrdout())) {
            return errorMandatory();
        }
        return null;
    }

    /**
     * source:fxtsss.0020.script
     */
    @Validate(path = "fxdgrp.rec.acc")
    public ValidResult checkFxdgrpRecAccN1000(FxtsssStoreBo bo) {
        if (MdaUtils.isEmpty(bo.getFxdgrp().getRec().getAcc())) {
            return errorMandatory();
        }
        return null;
    }

    /**
     * source:fxtsss.0021.script
     */
    @Validate(path = "fxdgrp.rec.acc2")
    public ValidResult checkFxdgrpRecAcc2N1000(FxtsssStoreBo bo) {
        if (MdaUtils.isEmpty(bo.getFxdgrp().getRec().getAcc2())) {
            return errorMandatory();
        }
        return null;
    }

    /**
     * source:fxtsss.0027.script
     */
    @Validate(path = "fxdgrp.rec.dsp")
    public ValidResult checkFxdgrpRecDspN1000(FxtsssStoreBo bo) {
        if (MdaUtils.isEmpty(bo.getFxdgrp().getRec().getDsp())) {
            return errorMandatory();
        }
        return null;
    }

    /**
     * source:fxtsss.0028.script
     */
    @Validate(path = "fxdgrp.rec.dsp2")
    public ValidResult checkFxdgrpRecDsp2N1000(FxtsssStoreBo bo) {
        if (MdaUtils.isEmpty(bo.getFxdgrp().getRec().getDsp2())) {
            return errorMandatory();
        }
        return null;
    }

}
