package com.brilliance.isc.funds.fxtsss.resource;

import com.brilliance.isc.common.context.SettleContext;
import com.brilliance.isc.common.transaction.controller.AbstractTransactionController;
import com.brilliance.isc.funds.fxtsss.service.FxtsssTransactionServiceImpl;
import com.brilliance.isc.funds.transfer.transaction.FxtsssStructMapper;
import com.brilliance.isc.funds.vo.funds.FxtsssStoreVo;
import com.brilliance.isc.transfer.IStructMapper;
import com.brilliance.isc.vo.ResponseSet;
import io.swagger.annotations.Api;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * @program: isc-funds
 * @ClassName: FxtsssResource
 * @description: 即期售汇 Fxtsss 请求入口
 * @author: huangshunlin
 * @create: 2024-10-08 15:34
 */
@RestController
@RequestMapping("/fxtsss")
@Api("即期售汇")
public class FxtsssResource extends AbstractTransactionController<FxtsssStoreVo> {

    @Resource
    private FxtsssStructMapper fxtsssStructMapper;

    public IStructMapper getStructMapper() {
        return fxtsssStructMapper;
    }

    @Resource(name = "fxtsss.transaction")
    FxtsssTransactionServiceImpl fxtsssTransactionService;

    @Autowired
    private SettleContext settleContext;

    /**
     * 根据结售汇类型 等获取业务参号
     *
     * @param fxtsssStoreVo
     * @return
     */
    @PostMapping("/getRef")
    public ResponseSet<String> getRef(@RequestBody FxtsssStoreVo fxtsssStoreVo) {
        String ref = fxtsssTransactionService.getRef(fxtsssStoreVo);
        return ResponseSet.simpleSuccess(ref);
    }

    @PostMapping("/defaultAccountsN1000")
    public ResponseSet defaultAccountsN1000(@RequestBody FxtsssStoreVo fxtsssStoreVo) {
        try {
            settleContext.loadSettleSession("FXTSSS", "", "");
            Map<String, List<String>> codeSet = fxtsssTransactionService.defaultAccountsN1000(fxtsssStoreVo);
            ResponseSet success = ResponseSet.simpleSuccess(fxtsssStoreVo);
            success.setCodeSet(codeSet);
            return success;
        } catch (Exception e) {
            throw e;
        } finally {
            SettleContext.removeUserSession();
        }
    }

    @PostMapping("/defaultRateN1000")
    public ResponseSet defaultRateN1000(@RequestBody FxtsssStoreVo fxtsssStoreVo) {
        try {
            settleContext.loadSettleSession("FXTSSS", "", "");
            fxtsssTransactionService.defaultRateN1000(fxtsssStoreVo);
            return ResponseSet.simpleSuccess(fxtsssStoreVo);
        } catch (Exception e) {
            throw e;
        } finally {
            SettleContext.removeUserSession();
        }

    }

    @PostMapping("/defaultCalculateN1100")
    public ResponseSet defaultCalculateN1100(@RequestBody FxtsssStoreVo fxtsssStoreVo) {
        try {
            settleContext.loadSettleSession("FXTSSS", "", "");
            fxtsssTransactionService.defaultCalculateN1100(fxtsssStoreVo);
            return ResponseSet.simpleSuccess(fxtsssStoreVo);
        } catch (Exception e) {
            throw e;
        } finally {
            SettleContext.removeUserSession();
        }

    }

}
